@@ -2,14 +2,12 @@
 
 from .codeql_installer import CodeQLInstaller
 from .codeql_runner import CodeQLRunner
-from .directory_manager import DirectoryManager
 from .language_detector import LanguageDetector, LanguageType
 from .logger import get_logger
 
 __all__ = [
     "CodeQLInstaller",
     "CodeQLRunner",
-    "DirectoryManager",
     "LanguageDetector",
     "LanguageType",
     "get_logger",
